;; dpp/theme.jl

;; Copyright (C) 2000 Daniel Lundin <daniel@codefactory.se>

;; sawmill is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; sawmill is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with sawmill; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

(defgroup dppOne "d++ Theme One"
  :group appearance)

(defcustom dppOne:normal-color "lightsteelblue4"
  "Color of inactive frames in `dppOne' frame style."
  :type color
  :group (appearance dppOne)
  :after-set after-setting-frame-option)

(defcustom dppOne:active-color "goldenrod"
  "Color of active frames in `dppOne' frame style."
  :type color
  :group (appearance dppOne)
  :after-set after-setting-frame-option)

(let*

;;
;; IMAGES
;;
    ((minimize (list (make-image "btn-inactive.png")
		     (make-image "minimize.png") 
		     nil (make-image "minimize-b.png")))

     (close (list (make-image "btn-inactive.png")
		  (make-image "close.png") 
		  nil (make-image "close-b.png")))
     
     (maximize (list (make-image "btn-inactive.png")
		     (make-image "maximize.png") 
		     nil (make-image "maximize-b.png")))
    ;; 7x19
     (top-left-images (list (make-image "top_left_inactive.png")
			    (make-image "top_left.png")))

     (top-right-images (list (make-image "top_right_inactive.png")
			    (make-image "top_right.png")))

     (bottom-right-images (list (make-image "bottom_right_inactive.png")
			    (make-image "bottom_right.png")))
     (angle-top-left-images (list (make-image "angle_top_left_inactive.png")
			    (make-image "angle_top_left.png")))
; Pretty title decoration
     (title-left-images (list (make-image "title_left_inactive.png")
			    (make-image "title_left.png")
			    ))

     (title-right-images (list (make-image "title_right_inactive.png")
			    (make-image "title_right.png")))

;;
;; COLORS
;;
     (frame-colors (lambda (w)
		     (list (or (window-get w 'frame-inactive-color)
			       dppOne:normal-color)
			   (or (window-get w 'frame-active-color)
			       dppOne:active-color))))

     (png-frame-colors (lambda (w)
		     (list "lightsteelblue4" "goldenrod")))

     (title-highlight-colors (lambda (w)
 		     (list "\#8493a5" "\#ffd36d")))


     (title-shadow-colors (lambda (w)
 		     (list "\#52525f" "\#997116")))


     (frame `(



; Title frame
	      ((background . "black")
	       (left-edge . -2)
	       (right-edge . -1)
	       (top-edge . -2)
	       (height . 2))

	      ((background . ,title-shadow-colors)
	       (left-edge . -2)
	       (right-edge . 0)
	       (top-edge . -3)
	       (height . 1))

; Titlebar

	      ((foreground . "black")
	       (background . ,png-frame-colors)
	       (text . ,window-name)
	       (x-justify . center)
	       (y-justify . -10)
	       (left-edge . 12)
	       (right-edge . 12)
	       (top-edge . -15)
	       (height . 12)
	       (class . title))

	      ((background . ,title-left-images)
	       (left-edge . 30)
	       (top-edge . -12)
	       (class . title))

	      ((background . ,title-right-images)
	       (right-edge . 42)
	       (top-edge . -12)
	       (class . title))


; Top frame	       
	      ((background . "black")
	       (left-edge . 13)
	       (right-edge . 13)
	       (top-edge . -17)
	       (height . 2)
               (class . top-border))

	      ((background . ,title-highlight-colors)
	       (left-edge . 13)
	       (right-edge . 13)
	       (top-edge . -15)
	       (height . 2)
               (class . top-border))

; Left frame	              
	      ((background . "black")
	       (left-edge . -2)
	       (width . 2)
	       (top-edge . -1)
	       (bottom-edge . -2)
               (class . left-border))

; Right frame	              
	     ((background . "black")
	       (right-edge . -1)
	       (width . 2)
	       (top-edge . -1)
	       (bottom-edge . 12)
               (class . right-border))
	       
       
; Bottom frame	              
	      ((background . "black")
	       (left-edge . 0)
	       (right-edge . 12)
	       (bottom-edge . -2)
	       (height . 2)
               (class . bottom-border))

; top-right corner
	      ((background . ,top-right-images)
	       (right-edge . -1)
	       (top-edge . -17)
	       (class . top-right-corner))

; top-left corner
	      ((background . ,top-left-images)
	       (left-edge . -2)
	       (top-edge . -17)
	       (class . top-left-corner))



; bottom-right corner
	      ((background . ,bottom-right-images)
	       (right-edge . -5)
	       (bottom-edge . -6)
	       (class . bottom-right-corner))
	       

; Buttons	       
	      ((background . ,close)
	       (left-edge . 12)
	       (top-edge . -17)
	       (class . close-button)
	       (removable . t))
	       
	      ((background . ,minimize)
	       (right-edge . 23)
	       (top-edge . -17)
	       (class . iconify-button)
	       (removable . t))

	      ((background . ,maximize)
	       (right-edge . 12)
	       (top-edge . -17)
	       (class . maximize-button)
	       (removable . t))))


     (transient-frame `(

; Top frame		 
			((background . "black")
			 (left-edge . 0)
			 (right-edge . 0)
			 (top-edge . -2)
			 (height . 2))
			 
; Left frame			 
			((background . "black")
			 (left-edge . -2)
			 (width . 2)
			 (top-edge . -2)
			 (bottom-edge . -2))

; Right frame			 
			((background . "black")
			 (right-edge . -2)
			 (width . 2)
			 (top-edge . -2)
			 (bottom-edge . -2))

; Bottom frame
			((background . "black")
			 (left-edge . 0)
			 (right-edge . 0)
			 (bottom-edge . -2)
			 (height . 2))

; bottom-right corner
			((background . ,bottom-right-images)
			 (right-edge . -6)
			 (bottom-edge . -7)
			 (class . bottom-right-corner))
; top-left corner
			((background . ,angle-top-left-images)
			 (left-edge . -6)
			 (top-edge . -7)
			 (class . title))
	      ))


     (shaped-transient-frame `(

; Top frame		 
			((background . "black")
			 (left-edge . -4)
			 (right-edge . -4)
			 (top-edge . -4)
			 (height . 4))

			((background . ,frame-colors)
			 (left-edge . -2)
			 (right-edge . -3)
			 (height . 1)
			 (top-edge . -3)
			 (class . title))
			 
; Left frame			 
			((background . "black")
			 (left-edge . -4)
			 (width . 4)
			 (top-edge . -2)
			 (bottom-edge . -4)
			 (class . title))

			((background . ,frame-colors)
			 (left-edge . -2)
			 (width . 1)
			 (top-edge . -3)
			 (bottom-edge . -3)
			 (class . title))

; Right frame			 
			((background . "black")
			 (right-edge . -4)
			 (width . 4)
			 (top-edge . 0)
			 (bottom-edge . -4)
			 (class . title))

			((background . ,frame-colors)
			 (right-edge . -3)
			 (width . 1)
			 (top-edge . 0)
			 (bottom-edge . -3)
			 (class . title))

			 
; Bottom frame
			((background . "black")
			 (left-edge . -1)
			 (right-edge . -2)
			 (bottom-edge . -4)
			 (height . 4)
			 (class . title))

			((background . ,frame-colors)
			 (left-edge . 1)
			 (right-edge . -3)
			 (bottom-edge . -3)
			 (height . 1)
			 (class . title)))))

  (add-frame-style 'dppOne
		   (lambda (w type)
		     (cond ((eq type 'default)
			    frame)
			   ((eq type 'transient)
			    transient-frame)
			   ((eq type 'shaped)
			    frame)
			   ((eq type 'shaped-transient)
			    shaped-transient-frame)
			   ((eq type 'unframed)
			    nil-frame)
			   (t
			    frame)))))
